@@ -164,6 +164,10 @@ FALLBACK_NOTIFY          : If defined, $Math::MPFR::doubletoa_fallback
 #include <inttypes.h>
 #endif
 
+#if MPFR_VERSION_MAJOR < 3
+#define mpfr_exp_t mp_exp_t
+#endif
+
 /*
  * In mpfr-4.1.0, the _Float128 type is exposed in mpfr.h if MPFR_WANT_FLOAT128 is defined.
  * We fall back to defining it to __float128 if the _Float128 type is unknown.
@@ -425,7 +429,7 @@ typedef _Decimal128 D128;
 
 # endif
 
-#elif defined(USE_LONG_DOUBLE)
+#elif defined(USE_LONG_DOUBLE) && REQUIRED_LDBL_MANT_DIG == 64
 #define MATH_MPFR_MAX_DIG 21
 #define NVSIZE_BITS 64
 #define MATH_MPFR_NV_MAX 0xf.fffffffffffffffp+16380L
